From 21c42819c757129a22326d8407b8ced16cb6d30b Mon Sep 17 00:00:00 2001
From: Max Kellermann <max@duempel.org>
Date: Tue, 2 Dec 2014 18:17:55 +0100
Subject: [PATCH] MixerType: rename to CamelCase

---
 src/mixer/MixerType.cxx | 2 +-
 src/mixer/MixerType.hxx | 8 ++++----
 src/output/Init.cxx     | 2 +-
 3 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/src/mixer/MixerType.cxx b/src/mixer/MixerType.cxx
index cd45db0d9..47016fd0a 100644
--- a/src/mixer/MixerType.cxx
+++ b/src/mixer/MixerType.cxx
@@ -23,7 +23,7 @@
 #include <assert.h>
 #include <string.h>
 
-enum mixer_type
+MixerType
 mixer_type_parse(const char *input)
 {
 	assert(input != NULL);
diff --git a/src/output/Init.cxx b/src/output/Init.cxx
index eafcec432..f195f6b8b 100644
--- a/src/output/Init.cxx
+++ b/src/output/Init.cxx
@@ -93,7 +93,7 @@ audio_output_detect(Error &error)
  * mixer_enabled, if the mixer_type setting is not configured.
  */
 gcc_pure
-static enum mixer_type
+static MixerType
 audio_output_mixer_type(const config_param &param)
 {
 	/* read the local "mixer_type" setting */
diff --git a/src/mixer/MixerType.hxx b/src/mixer/MixerType.hxx
index bfa2637b7..a5e635e06 100644
--- a/src/mixer/MixerType.hxx
+++ b/src/mixer/MixerType.hxx
@@ -20,7 +20,7 @@
 #ifndef MPD_MIXER_TYPE_HXX
 #define MPD_MIXER_TYPE_HXX
 
-enum mixer_type {
+enum MixerType {
 	/** parser error */
 	MIXER_TYPE_UNKNOWN,
 
@@ -35,13 +35,13 @@ enum mixer_type {
 };
 
 /**
  * Parses a "mixer_type" setting from the configuration file.
  *
  * @param input the configured string value; must not be NULL
  * @return a #mixer_type value; MIXER_TYPE_UNKNOWN means #input could
  * not be parsed
  */
-enum mixer_type
+MixerType
 mixer_type_parse(const char *input);
 
 #endif
@@ -35,13 +35,13 @@ enum mixer_type {
 
 /**
- * Parses a "mixer_type" setting from the configuration file.
+ * Parses a #MixerType setting from the configuration file.
  *
  * @param input the configured string value; must not be NULL
@@ -35,13 +35,13 @@ enum mixer_type {
  *
  * @param input the configured string value; must not be NULL
- * @return a #mixer_type value; MIXER_TYPE_UNKNOWN means #input could
+ * @return a #MixerType value; MIXER_TYPE_UNKNOWN means #input could
  * not be parsed
  */